@@ -146,6 +146,11 @@ class Cache:
     def sync_to_async_get_model_fields(self, django_model):
         return list(django_model._meta.get_fields())
 
+    def check_pause(self):
+        while True:
+            if not self.redis_root.is_paused:
+                break
+
     @sync_to_async
     def sync_to_async_update_or_create_django_instance_from_redis_instance(
             self,
@@ -157,10 +162,9 @@ class Cache:
     ):
         need_to_create = True
         if django_id not in ['null', None]:
+            self.check_pause()
             if django_model.objects.filter(id=django_id):
                 need_to_create = False
-        print()
-        print(need_to_create)
         django_instance = None
 
         if need_to_create:
@@ -188,6 +192,9 @@ class Cache:
                       f'and many to many params\n'
                       f'{django_many_to_many_params}'
                       f'\n')
+            print(f'now django {django_model.__name__}: {len(django_model.objects.all())}\n'
+                  f'now redis {django_model.__name__}: {len(self.redis_root.get(django_model))}'
+                  '\n\n\n')
         else:
             django_instance = django_model.objects.filter(id=django_id)[0]
             changed_fields_to_update = {}
@@ -219,7 +226,6 @@ class Cache:
                         changed_many_to_many_fields_to_update
                     )
                 django_instance = django_model.objects.filter(id=django_id)[0]
-                print('updated', django_id)
             else:
                 print(f'\n'
                       f'{datetime.datetime.now()} - '
@@ -229,9 +235,6 @@ class Cache:
                       f'and many to many params\n'
                       f'{changed_many_to_many_fields_to_update}'
                       f'\n')
-        print(f'now django {django_model.__name__}: {len(django_model.objects.all())}\n'
-              f'now redis {django_model.__name__}: {len(self.redis_root.get(django_model))}'
-              '\n\n\n')
         return django_instance
 
     def update_django_many_to_many(
