@@ -439,6 +439,7 @@ class RedisRoot:
         self.ignore_deserialization_errors = ignore_deserialization_errors
         self.save_consistency = save_consistency
         self.economy = economy
+        self.set_pause(False)
 
     @property
     def redis_instance(self):
@@ -449,6 +450,15 @@ class RedisRoot:
     def cached_models(self):
         return self.registered_models
 
+    def set_pause(self, paused=False):
+        self.redis_instance.set(f'{self.prefix}:_paused', int(bool(paused)))
+
+    @property
+    def is_paused(self):
+        raw_paused = self.redis_instance.get(f'{self.prefix}:_paused')
+        paused = bool(int(raw_paused))
+        return paused
+
     def _get_django_models_to_cache(self):
         django_models_to_cache = {}
         for django_model, django_model_cache_data in self.registered_django_models.items():
