@@ -7,22 +7,25 @@ from django.db.models.query_utils import DeferredAttribute
 class RedisQuerySet(django_models.query.QuerySet):
 
     def update(self, **kwargs):
+        redis_root = get_redis_root()
+        redis_root.set_paused(True)
         update_result = super().update(**kwargs)
         concrete_model = self.model
-        redis_root = get_redis_root()
         id = concrete_model.id
         django_ids_to_update = [int(django_instance.id) for django_instance in self]
         data_to_update = redis_root.get(self.model, django_id__in=django_ids_to_update)
         redis_root.update(self.model, data_to_update, **kwargs)
+        redis_root.set_paused(False)
         return self
 
     def create(self, **kwargs):
+        redis_root = get_redis_root()
+        redis_root.set_paused(True)
         create_result = super().create(**kwargs)
         concrete_model = self.model._meta.concrete_model
         create_result = create_result
         id = create_result.id
         existing_fields = {}
-        redis_root = get_redis_root()
         for field in create_result.__class__._meta.get_fields():
             try:
                 field_name = field.name
@@ -45,14 +48,15 @@ class RedisQuerySet(django_models.query.QuerySet):
             redis_root.update(self.model, existing_redis_instances, **existing_fields)
         else:
             redis_root.create(self.model, **existing_fields)
-
+        redis_root.set_paused(False)
         return create_result
 
     def delete(self):
+        redis_root = get_redis_root()
+        redis_root.set_paused(True)
         list_self = list(self).copy()
         concrete_model = self.model._meta.concrete_model
         delete_result = super().delete()
-        redis_root = get_redis_root()
         django_instance_ids_to_delete = [int(django_instance.id) for django_instance in list_self]
         print(django_instance_ids_to_delete)
         data_to_delete = redis_root.get(self.model, django_id__in=django_instance_ids_to_delete)
@@ -60,6 +64,7 @@ class RedisQuerySet(django_models.query.QuerySet):
         redis_root.delete(self.model, data_to_delete)
         data_to_delete = redis_root.get(self.model, django_id__in=django_instance_ids_to_delete)
         print('after delete: ', len(data_to_delete))
+        redis_root.set_paused(False)
         return list_self
 
 class RedisUserObjectsManager(UserManager):
@@ -142,6 +147,7 @@ def get_or_create_redis_instance_from_django_instance(
     ):
         django_fields = django_instance.__class__._meta.get_fields()
         django_instance_model = django_instance.__class__
+        redis_root.set_paused(True)
         redis_instance = redis_root.get(django_instance_model, django_id=django_instance.id)
 
         if not redis_instance:
@@ -158,6 +164,7 @@ def get_or_create_redis_instance_from_django_instance(
             )
         else:
             redis_instance = redis_instance[0]
+        redis_root.set_paused(False)
 
         return redis_instance
 
@@ -195,9 +202,10 @@ class DjangoRedisModel(django_models.Model):
     objects = RedisObjectsManager()
 
     def save(self, *args, **kwargs):
+        redis_root = get_redis_root()
+        redis_root.set_paused(True)
         save_result = super().save(*args, **kwargs)
         existing_fields = {}
-        redis_root = get_redis_root()
         for field in self.__class__._meta.get_fields():
             try:
                 field_name = field.name
@@ -214,10 +222,15 @@ class DjangoRedisModel(django_models.Model):
         redis_instance_qs = redis_root.get(self.__class__, django_id=self.id)
         if redis_instance_qs:
             redis_root.update(self.__class__, redis_instance_qs, **existing_fields)
+        else:
+            redis_root.create(self.__class__, redis_instance_qs, **existing_fields)
+        redis_root.set_paused(False)
         return self
 
     def delete(self, *args, **kwargs):
         django_id = int(self.id)
+        redis_root = get_redis_root()
+        redis_root.set_paused(True)
         delete_result = super().delete(*args, **kwargs)
         redis_root = get_redis_root()
         redis_instance_qs = redis_root.get(self.__class__, django_id=django_id)
@@ -227,7 +240,7 @@ class DjangoRedisModel(django_models.Model):
             redis_root.delete(self.__class__, redis_instance_qs)
             redis_instance_qs = redis_root.get(self.__class__, django_id=django_id)
             print('model post delete: ', len(redis_instance_qs))
-
+        redis_root.set_paused(False)
         return self
 
     class Meta:
@@ -238,9 +251,10 @@ class DjangoRedisUserModel(AbstractUser):
     objects = RedisUserObjectsManager()
 
     def save(self, *args, **kwargs):
+        redis_root = get_redis_root()
+        redis_root.set_paused(True)
         save_result = super().save(*args, **kwargs)
         existing_fields = {}
-        redis_root = get_redis_root()
         for field in self.__class__._meta.get_fields():
             try:
                 field_name = field.name
@@ -257,10 +271,15 @@ class DjangoRedisUserModel(AbstractUser):
         redis_instance_qs = redis_root.get(self.__class__, django_id=self.id)
         if redis_instance_qs:
             redis_root.update(self.__class__, redis_instance_qs, **existing_fields)
+        else:
+            redis_root.create(self.__class__, redis_instance_qs, **existing_fields)
+        redis_root.set_paused(False)
         return self
 
     def delete(self, *args, **kwargs):
         django_id = int(self.id)
+        redis_root = get_redis_root()
+        redis_root.set_paused(True)
         delete_result = super().delete(*args, **kwargs)
         redis_root = get_redis_root()
         redis_instance_qs = redis_root.get(self.__class__, django_id=django_id)
@@ -270,7 +289,7 @@ class DjangoRedisUserModel(AbstractUser):
             redis_root.delete(self.__class__, redis_instance_qs)
             redis_instance_qs = redis_root.get(self.__class__, django_id=django_id)
             print('model post delete: ', len(redis_instance_qs))
-
+        redis_root.set_paused(False)
         return self
 
     class Meta:
